"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ramda_1 = require("ramda");
var Snapshot;
(function (Snapshot) {
    const runPluginSnapshot = (runPlugin, context) => __awaiter(this, void 0, void 0, function* () {
        if (typeof runPlugin.snapshot === 'string') {
            // Just a file copy
            const { filesystem, system } = context;
            // @ts-ignore -- strictNullChecks strikes
            filesystem.copy(`${runPlugin.templateDirectory}${runPlugin.snapshot}`, '.solidarity');
            // force local version update
            // @ts-ignore -- strictNullChecks strikes
            yield system.run('solidarity snapshot');
        }
        else {
            // run plugin's snapshot function
            yield runPlugin.snapshot(context);
        }
    });
    const createSolidarityFile = (context) => __awaiter(this, void 0, void 0, function* () {
        const { print, printSeparator } = context;
        const pluginsWithTemplates = ramda_1.filter(plugin => plugin.templateDirectory !== null, context._pluginsList);
        // list visible plugins
        printSeparator();
        print.info('Available technology plugins:\n');
        if (pluginsWithTemplates.length > 0) {
            const pluginOptions = ["NONE" /* NONE */];
            pluginsWithTemplates.map(plugin => {
                print.info(`   ${plugin.name}:\t ${plugin.description}`);
                pluginOptions.unshift(plugin.name);
            });
            printSeparator();
            const answer = yield context.prompt.ask({
                name: 'selectedPlugin',
                message: 'Which of the above technology snapshots will you use for this project?',
                type: 'list',
                choices: pluginOptions,
            });
            if (answer.selectedPlugin === "NONE" /* NONE */) {
                print.info("Nothing to do \u00AF\\_(\u30C4)_/\u00AF" /* NOTHING */);
            }
            else {
                const pluginSpinner = print.spin(`Running ${answer.selectedPlugin} Snapshot`);
                // Config for selected plugin only
                const runPlugin = ramda_1.head(ramda_1.filter(ramda_1.propEq('name', answer.selectedPlugin), pluginsWithTemplates));
                // run plugin
                yield runPluginSnapshot(runPlugin, context);
                pluginSpinner.succeed('Snapshot complete');
            }
        }
        else {
            print.error(`No solidarity plugins found!
      Add a plugin for a given technology:
      ${print.colors.blue('https://github.com/infinitered/solidarity/blob/master/docs/pluginsList.md')}
      OR write your own plugin for generating rules:
      ${print.colors.blue('https://github.com/infinitered/solidarity/blob/master/docs/plugins.md')}
      OR simply create a .solidarity rule-set by hand for this project:
      ${print.colors.blue('https://github.com/infinitered/solidarity/blob/master/docs/options.md')}
      `);
            printSeparator();
        }
    });
    Snapshot.run = (context) => __awaiter(this, void 0, void 0, function* () {
        const { print, prompt, filesystem, solidarity, parameters } = context;
        const { first } = parameters;
        const { setSolidaritySettings, appendSolidaritySettings, buildSpecificRequirement } = solidarity;
        // Node Modules Quirk
        require('../extensions/functions/quirksNodeModules');
        // check is there an existing .solidarity file?
        if (filesystem.exists('.solidarity')) {
            // load existing file and update rule versions
            if (first) {
                yield buildSpecificRequirement(context)
                    .then(newRequirement => {
                    const updatedSolidaritySettings = appendSolidaritySettings(context, newRequirement);
                    setSolidaritySettings(updatedSolidaritySettings, context);
                })
                    .catch(error => {
                    if (error)
                        print.error(error);
                    print.error('Your new requirement was not added.');
                });
            }
            else {
                print.info('Now loading latest environment');
                solidarity.updateVersions(context);
            }
        }
        else {
            // Find out what they wanted
            const userAnswer = yield prompt.ask({
                name: 'createFile',
                type: 'confirm',
                message: 'No `.solidarity` file found for this project.  Would you like to create one?',
            });
            if (userAnswer.createFile) {
                yield createSolidarityFile(context);
            }
            else {
                print.info("Nothing to do \u00AF\\_(\u30C4)_/\u00AF" /* NOTHING */);
            }
        }
    });
})(Snapshot || (Snapshot = {}));
module.exports = {
    description: 'Take a snapshot of the versions and store in solidarity file',
    alias: 's',
    run: Snapshot.run,
};
//# sourceMappingURL=snapshot.js.map